@@ -1,19 +1,17 @@
 package CHI::Driver::CacheCache;
-BEGIN {
-  $CHI::Driver::CacheCache::VERSION = '0.56';
-}
+$CHI::Driver::CacheCache::VERSION = '0.59';
 use Cache::Cache;
 use Carp;
-use Moose;
+use Moo;
+use MooX::Types::MooseLike::Base qw(:all);
+use Module::Runtime qw(require_module);
 use strict;
 use warnings;
 
 extends 'CHI::Driver::Base::CacheContainer';
 
-has 'cc_class'   => ( is => 'ro', isa => 'Str', required => 1 );
-has 'cc_options' => ( is => 'ro', isa => 'HashRef', required => 1 );
-
-__PACKAGE__->meta->make_immutable();
+has 'cc_class'   => ( is => 'ro', isa => Str, required => 1 );
+has 'cc_options' => ( is => 'ro', isa => HashRef, required => 1 );
 
 sub BUILD {
     my ( $self, $params ) = @_;
@@ -28,7 +26,7 @@ sub _build_contained_cache {
     my $cc_options = $self->{cc_options};
     my %subparams  = ( namespace => $self->namespace );
 
-    Class::MOP::load_class($cc_class);
+    require_module($cc_class);
 
     my %final_cc_params = ( %subparams, %{$cc_options} );
 
@@ -37,7 +35,7 @@ sub _build_contained_cache {
 
 1;
 
-
+__END__
 
 =pod
 
@@ -47,7 +45,7 @@ CHI::Driver::CacheCache - CHI wrapper for Cache::Cache
 
 =head1 VERSION
 
-version 0.56
+version 0.59
 
 =head1 SYNOPSIS
 
@@ -96,7 +94,3 @@ This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
-
-__END__
-
